@@ -1,7 +1,10 @@
 import logging
+from typing import Optional
 
 from python_search.apps.window_manager import WindowManager
-from python_search.config import ConfigurationLoader, PythonSearchConfiguration
+from python_search.configuration.configuration import PythonSearchConfiguration
+from python_search.configuration.loader import ConfigurationLoader
+from python_search.core_entities import Key
 from python_search.entry_runner import EntryRunner
 from python_search.environment import is_mac
 from python_search.events.run_performed import RunPerformed
@@ -24,7 +27,7 @@ class PythonSearchCli:
 
     @staticmethod
     def install_dependencies():
-        """install dependenceis"""
+        """install dependencies"""
         from python_search.init.install_dependencies import InstallDependencies
 
         InstallDependencies().install_all()
@@ -43,7 +46,7 @@ class PythonSearchCli:
 
         Project().set_current_project(location)
 
-    def __init__(self, configuration: PythonSearchConfiguration = None):
+    def __init__(self, configuration: Optional[PythonSearchConfiguration] = None):
         """
         Keep this constructor small and import dependencies inside the functions
         so they keep being fast
@@ -82,10 +85,10 @@ class PythonSearchCli:
 
     def edit_key(self, entry_str):
         """Opens the key in the source code using the IDE specified in the config, defaults to vim"""
-        from python_search.entry_capture.edit_content import EditKey
+        key = str(Key.from_fzf(entry_str))
 
-        result = EditKey(self.configuration).edit_key(entry_str, dry_run=False)
-        key = entry_str.split(":")[0]
+        from python_search.entry_capture.edit_content import EditKey
+        result = EditKey(self.configuration).edit_key(key, dry_run=False)
         LogRunPerformedClient().send(
             RunPerformed(key=key, query_input="", shortcut=False)
         )
@@ -97,10 +100,9 @@ class PythonSearchCli:
         Used by fzf to provide Ctrl-c functionality.
         """
         from python_search.interpreter.interpreter_matcher import InterpreterMatcher
+        key = str(Key.from_fzf(entry_str))
 
-        key = entry_str.split(":")[0]
         InterpreterMatcher.build_instance(self.configuration).clipboard(key)
-        print(f"Key: {key}")
         LogRunPerformedClient().send(
             RunPerformed(key=key, query_input="", shortcut=False)
         )
@@ -175,10 +177,6 @@ class PythonSearchCli:
         """
         Preview().display(entry_text)
 
-    def _infra_report(self):
-        from python_search.infrastructure.report import Report
-
-        return Report()
 
     def _entry_type_classifier(self):
 
