@@ -10,7 +10,7 @@ def setup_inference_logger():
     # fh.setLevel(logging.DEBUG)
     # logger.addHandler(fh)
 
-    ch = logging.StreamHandler()
+    ch = logging.StreamHandler(sys.stdout)
     ch.setLevel(logging.INFO)
     logger.addHandler(ch)
 
@@ -37,16 +37,26 @@ def setup_run_key_logger():
 
     return logger
 
+def interpreter_logger():
+    logger = logging.getLogger("interpeter_logger")
+    ch = logging.StreamHandler(sys.stdout)
+    ch.setLevel(logging.INFO)
+    logger.addHandler(ch)
+    fh = logging.FileHandler(f"/tmp/debug_interpreter")
+    fh.setLevel(logging.INFO)
+    logger.addHandler(fh)
+    return logger
+
 
 def setup_data_writter_logger(event_name):
     logger = logging.getLogger(f"data-writer_{event_name}")
     logger.setLevel(logging.DEBUG)
     fh = logging.FileHandler(f"/tmp/data-writer_event_{event_name}")
     fh.setLevel(logging.DEBUG)
-    ch = logging.StreamHandler()
-    ch.setLevel(logging.INFO)
+    #ch = logging.StreamHandler()
+    #ch.setLevel(logging.INFO)
     logger.addHandler(fh)
-    logger.addHandler(ch)
+    #logger.addHandler(ch)
 
     return logger
 
